Class: OpenapiClient::AlertRule
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- OpenapiClient::AlertRule
- Defined in:
- lib/openapi_client/models/alert_rule.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#channels ⇒ Object
Returns the value of attribute channels.
-
#condition ⇒ Object
Returns the value of attribute condition.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#id ⇒ Object
Returns the value of attribute id.
-
#is_active ⇒ Object
Returns the value of attribute is_active.
-
#name ⇒ Object
Returns the value of attribute name.
-
#threshold ⇒ Object
Returns the value of attribute threshold.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AlertRule
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AlertRule
Initializes the object
98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/openapi_client/models/alert_rule.rb', line 98 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `OpenapiClient::AlertRule` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `OpenapiClient::AlertRule`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'condition') self.condition = attributes[:'condition'] end if attributes.key?(:'threshold') self.threshold = attributes[:'threshold'] end if attributes.key?(:'channels') if (value = attributes[:'channels']).is_a?(Array) self.channels = value end end if attributes.key?(:'is_active') self.is_active = attributes[:'is_active'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end end |
Instance Attribute Details
#channels ⇒ Object
Returns the value of attribute channels.
26 27 28 |
# File 'lib/openapi_client/models/alert_rule.rb', line 26 def channels @channels end |
#condition ⇒ Object
Returns the value of attribute condition.
22 23 24 |
# File 'lib/openapi_client/models/alert_rule.rb', line 22 def condition @condition end |
#created_at ⇒ Object
Returns the value of attribute created_at.
30 31 32 |
# File 'lib/openapi_client/models/alert_rule.rb', line 30 def created_at @created_at end |
#id ⇒ Object
Returns the value of attribute id.
18 19 20 |
# File 'lib/openapi_client/models/alert_rule.rb', line 18 def id @id end |
#is_active ⇒ Object
Returns the value of attribute is_active.
28 29 30 |
# File 'lib/openapi_client/models/alert_rule.rb', line 28 def is_active @is_active end |
#name ⇒ Object
Returns the value of attribute name.
20 21 22 |
# File 'lib/openapi_client/models/alert_rule.rb', line 20 def name @name end |
#threshold ⇒ Object
Returns the value of attribute threshold.
24 25 26 |
# File 'lib/openapi_client/models/alert_rule.rb', line 24 def threshold @threshold end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
68 69 70 |
# File 'lib/openapi_client/models/alert_rule.rb', line 68 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
73 74 75 |
# File 'lib/openapi_client/models/alert_rule.rb', line 73 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/openapi_client/models/alert_rule.rb', line 55 def self.attribute_map { :'id' => :'id', :'name' => :'name', :'condition' => :'condition', :'threshold' => :'threshold', :'channels' => :'channels', :'is_active' => :'is_active', :'created_at' => :'created_at' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 |
# File 'lib/openapi_client/models/alert_rule.rb', line 199 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
91 92 93 94 |
# File 'lib/openapi_client/models/alert_rule.rb', line 91 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/openapi_client/models/alert_rule.rb', line 78 def self.openapi_types { :'id' => :'String', :'name' => :'String', :'condition' => :'String', :'threshold' => :'Integer', :'channels' => :'Array<String>', :'is_active' => :'Boolean', :'created_at' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
172 173 174 175 176 177 178 179 180 181 182 |
# File 'lib/openapi_client/models/alert_rule.rb', line 172 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && name == o.name && condition == o.condition && threshold == o.threshold && channels == o.channels && is_active == o.is_active && created_at == o.created_at end |
#eql?(o) ⇒ Boolean
186 187 188 |
# File 'lib/openapi_client/models/alert_rule.rb', line 186 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
192 193 194 |
# File 'lib/openapi_client/models/alert_rule.rb', line 192 def hash [id, name, condition, threshold, channels, is_active, created_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
145 146 147 148 149 |
# File 'lib/openapi_client/models/alert_rule.rb', line 145 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
221 222 223 224 225 226 227 228 229 230 231 232 233 |
# File 'lib/openapi_client/models/alert_rule.rb', line 221 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
153 154 155 156 157 158 |
# File 'lib/openapi_client/models/alert_rule.rb', line 153 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' condition_validator = EnumAttributeValidator.new('String', ["failure_rate", "latency", "consecutive_failures"]) return false unless condition_validator.valid?(@condition) true end |