Class: OpenapiClient::CreateEndpointRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- OpenapiClient::CreateEndpointRequest
- Defined in:
- lib/openapi_client/models/create_endpoint_request.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#allowed_ips ⇒ Object
Returns the value of attribute allowed_ips.
-
#custom_headers ⇒ Object
Returns the value of attribute custom_headers.
-
#description ⇒ Object
Returns the value of attribute description.
-
#event_filter ⇒ Object
Returns the value of attribute event_filter.
-
#fallback_url ⇒ Object
Returns the value of attribute fallback_url.
-
#format ⇒ Object
Returns the value of attribute format.
-
#retry_policy ⇒ Object
Returns the value of attribute retry_policy.
-
#routing_strategy ⇒ Object
Returns the value of attribute routing_strategy.
-
#url ⇒ Object
Returns the value of attribute url.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateEndpointRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CreateEndpointRequest
Initializes the object
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/openapi_client/models/create_endpoint_request.rb', line 106 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `OpenapiClient::CreateEndpointRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `OpenapiClient::CreateEndpointRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'url') self.url = attributes[:'url'] else self.url = nil end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'allowed_ips') if (value = attributes[:'allowed_ips']).is_a?(Array) self.allowed_ips = value end end if attributes.key?(:'event_filter') if (value = attributes[:'event_filter']).is_a?(Array) self.event_filter = value end end if attributes.key?(:'custom_headers') self.custom_headers = attributes[:'custom_headers'] end if attributes.key?(:'retry_policy') self.retry_policy = attributes[:'retry_policy'] end if attributes.key?(:'routing_strategy') self.routing_strategy = attributes[:'routing_strategy'] end if attributes.key?(:'fallback_url') self.fallback_url = attributes[:'fallback_url'] end if attributes.key?(:'format') self.format = attributes[:'format'] else self.format = 'standard' end end |
Instance Attribute Details
#allowed_ips ⇒ Object
Returns the value of attribute allowed_ips.
22 23 24 |
# File 'lib/openapi_client/models/create_endpoint_request.rb', line 22 def allowed_ips @allowed_ips end |
#custom_headers ⇒ Object
Returns the value of attribute custom_headers.
26 27 28 |
# File 'lib/openapi_client/models/create_endpoint_request.rb', line 26 def custom_headers @custom_headers end |
#description ⇒ Object
Returns the value of attribute description.
20 21 22 |
# File 'lib/openapi_client/models/create_endpoint_request.rb', line 20 def description @description end |
#event_filter ⇒ Object
Returns the value of attribute event_filter.
24 25 26 |
# File 'lib/openapi_client/models/create_endpoint_request.rb', line 24 def event_filter @event_filter end |
#fallback_url ⇒ Object
Returns the value of attribute fallback_url.
32 33 34 |
# File 'lib/openapi_client/models/create_endpoint_request.rb', line 32 def fallback_url @fallback_url end |
#format ⇒ Object
Returns the value of attribute format.
34 35 36 |
# File 'lib/openapi_client/models/create_endpoint_request.rb', line 34 def format @format end |
#retry_policy ⇒ Object
Returns the value of attribute retry_policy.
28 29 30 |
# File 'lib/openapi_client/models/create_endpoint_request.rb', line 28 def retry_policy @retry_policy end |
#routing_strategy ⇒ Object
Returns the value of attribute routing_strategy.
30 31 32 |
# File 'lib/openapi_client/models/create_endpoint_request.rb', line 30 def routing_strategy @routing_strategy end |
#url ⇒ Object
Returns the value of attribute url.
18 19 20 |
# File 'lib/openapi_client/models/create_endpoint_request.rb', line 18 def url @url end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
74 75 76 |
# File 'lib/openapi_client/models/create_endpoint_request.rb', line 74 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
79 80 81 |
# File 'lib/openapi_client/models/create_endpoint_request.rb', line 79 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/openapi_client/models/create_endpoint_request.rb', line 59 def self.attribute_map { :'url' => :'url', :'description' => :'description', :'allowed_ips' => :'allowed_ips', :'event_filter' => :'event_filter', :'custom_headers' => :'custom_headers', :'retry_policy' => :'retry_policy', :'routing_strategy' => :'routing_strategy', :'fallback_url' => :'fallback_url', :'format' => :'format' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 |
# File 'lib/openapi_client/models/create_endpoint_request.rb', line 250 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
99 100 101 102 |
# File 'lib/openapi_client/models/create_endpoint_request.rb', line 99 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/openapi_client/models/create_endpoint_request.rb', line 84 def self.openapi_types { :'url' => :'String', :'description' => :'String', :'allowed_ips' => :'Array<String>', :'event_filter' => :'Array<String>', :'custom_headers' => :'Object', :'retry_policy' => :'RetryPolicy', :'routing_strategy' => :'String', :'fallback_url' => :'String', :'format' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
221 222 223 224 225 226 227 228 229 230 231 232 233 |
# File 'lib/openapi_client/models/create_endpoint_request.rb', line 221 def ==(o) return true if self.equal?(o) self.class == o.class && url == o.url && description == o.description && allowed_ips == o.allowed_ips && event_filter == o.event_filter && custom_headers == o.custom_headers && retry_policy == o.retry_policy && routing_strategy == o.routing_strategy && fallback_url == o.fallback_url && format == o.format end |
#eql?(o) ⇒ Boolean
237 238 239 |
# File 'lib/openapi_client/models/create_endpoint_request.rb', line 237 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
243 244 245 |
# File 'lib/openapi_client/models/create_endpoint_request.rb', line 243 def hash [url, description, allowed_ips, event_filter, custom_headers, retry_policy, routing_strategy, fallback_url, format].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
167 168 169 170 171 172 173 174 175 |
# File 'lib/openapi_client/models/create_endpoint_request.rb', line 167 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @url.nil? invalid_properties.push('invalid value for "url", url cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
272 273 274 275 276 277 278 279 280 281 282 283 284 |
# File 'lib/openapi_client/models/create_endpoint_request.rb', line 272 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
179 180 181 182 183 184 185 186 187 |
# File 'lib/openapi_client/models/create_endpoint_request.rb', line 179 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @url.nil? routing_strategy_validator = EnumAttributeValidator.new('String', ["round-robin", "latency", "failover"]) return false unless routing_strategy_validator.valid?(@routing_strategy) format_validator = EnumAttributeValidator.new('String', ["standard", "cloudevents"]) return false unless format_validator.valid?(@format) true end |