Class: OpenapiClient::CustomerResponse

Inherits:
ApiModelBase show all
Defined in:
lib/openapi_client/models/customer_response.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CustomerResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'lib/openapi_client/models/customer_response.rb', line 109

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `OpenapiClient::CustomerResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `OpenapiClient::CustomerResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'email')
    self.email = attributes[:'email']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'api_key')
    self.api_key = attributes[:'api_key']
  end

  if attributes.key?(:'plan')
    self.plan = attributes[:'plan']
  end

  if attributes.key?(:'webhook_limit')
    self.webhook_limit = attributes[:'webhook_limit']
  end

  if attributes.key?(:'webhook_count')
    self.webhook_count = attributes[:'webhook_count']
  end

  if attributes.key?(:'is_admin')
    self.is_admin = attributes[:'is_admin']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end
end

Instance Attribute Details

#api_keyObject

Only returned on registration



25
26
27
# File 'lib/openapi_client/models/customer_response.rb', line 25

def api_key
  @api_key
end

#created_atObject

Returns the value of attribute created_at.



35
36
37
# File 'lib/openapi_client/models/customer_response.rb', line 35

def created_at
  @created_at
end

#emailObject

Returns the value of attribute email.



20
21
22
# File 'lib/openapi_client/models/customer_response.rb', line 20

def email
  @email
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/openapi_client/models/customer_response.rb', line 18

def id
  @id
end

#is_adminObject

Returns the value of attribute is_admin.



33
34
35
# File 'lib/openapi_client/models/customer_response.rb', line 33

def is_admin
  @is_admin
end

#nameObject

Returns the value of attribute name.



22
23
24
# File 'lib/openapi_client/models/customer_response.rb', line 22

def name
  @name
end

#planObject

Returns the value of attribute plan.



27
28
29
# File 'lib/openapi_client/models/customer_response.rb', line 27

def plan
  @plan
end

#webhook_countObject

Returns the value of attribute webhook_count.



31
32
33
# File 'lib/openapi_client/models/customer_response.rb', line 31

def webhook_count
  @webhook_count
end

#webhook_limitObject

Returns the value of attribute webhook_limit.



29
30
31
# File 'lib/openapi_client/models/customer_response.rb', line 29

def webhook_limit
  @webhook_limit
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



75
76
77
# File 'lib/openapi_client/models/customer_response.rb', line 75

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



80
81
82
# File 'lib/openapi_client/models/customer_response.rb', line 80

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



60
61
62
63
64
65
66
67
68
69
70
71
72
# File 'lib/openapi_client/models/customer_response.rb', line 60

def self.attribute_map
  {
    :'id' => :'id',
    :'email' => :'email',
    :'name' => :'name',
    :'api_key' => :'api_key',
    :'plan' => :'plan',
    :'webhook_limit' => :'webhook_limit',
    :'webhook_count' => :'webhook_count',
    :'is_admin' => :'is_admin',
    :'created_at' => :'created_at'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
# File 'lib/openapi_client/models/customer_response.rb', line 218

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



100
101
102
103
104
105
# File 'lib/openapi_client/models/customer_response.rb', line 100

def self.openapi_nullable
  Set.new([
    :'name',
    :'api_key',
  ])
end

.openapi_typesObject

Attribute type mapping.



85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/openapi_client/models/customer_response.rb', line 85

def self.openapi_types
  {
    :'id' => :'String',
    :'email' => :'String',
    :'name' => :'String',
    :'api_key' => :'String',
    :'plan' => :'String',
    :'webhook_limit' => :'Integer',
    :'webhook_count' => :'Integer',
    :'is_admin' => :'Boolean',
    :'created_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'lib/openapi_client/models/customer_response.rb', line 189

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      email == o.email &&
      name == o.name &&
      api_key == o.api_key &&
      plan == o.plan &&
      webhook_limit == o.webhook_limit &&
      webhook_count == o.webhook_count &&
      is_admin == o.is_admin &&
      created_at == o.created_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


205
206
207
# File 'lib/openapi_client/models/customer_response.rb', line 205

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



211
212
213
# File 'lib/openapi_client/models/customer_response.rb', line 211

def hash
  [id, email, name, api_key, plan, webhook_limit, webhook_count, is_admin, created_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



162
163
164
165
166
# File 'lib/openapi_client/models/customer_response.rb', line 162

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



240
241
242
243
244
245
246
247
248
249
250
251
252
# File 'lib/openapi_client/models/customer_response.rb', line 240

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



170
171
172
173
174
175
# File 'lib/openapi_client/models/customer_response.rb', line 170

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  plan_validator = EnumAttributeValidator.new('String', ["free", "pro", "business"])
  return false unless plan_validator.valid?(@plan)
  true
end