Class: OpenapiClient::Delivery

Inherits:
ApiModelBase show all
Defined in:
lib/openapi_client/models/delivery.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Delivery

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
# File 'lib/openapi_client/models/delivery.rb', line 104

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `OpenapiClient::Delivery` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `OpenapiClient::Delivery`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'endpoint_id')
    self.endpoint_id = attributes[:'endpoint_id']
  end

  if attributes.key?(:'event')
    self.event = attributes[:'event']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'attempt_count')
    self.attempt_count = attributes[:'attempt_count']
  end

  if attributes.key?(:'response_status')
    self.response_status = attributes[:'response_status']
  end

  if attributes.key?(:'replay_count')
    self.replay_count = attributes[:'replay_count']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end
end

Instance Attribute Details

#attempt_countObject

Returns the value of attribute attempt_count.



26
27
28
# File 'lib/openapi_client/models/delivery.rb', line 26

def attempt_count
  @attempt_count
end

#created_atObject

Returns the value of attribute created_at.



32
33
34
# File 'lib/openapi_client/models/delivery.rb', line 32

def created_at
  @created_at
end

#endpoint_idObject

Returns the value of attribute endpoint_id.



20
21
22
# File 'lib/openapi_client/models/delivery.rb', line 20

def endpoint_id
  @endpoint_id
end

#eventObject

Returns the value of attribute event.



22
23
24
# File 'lib/openapi_client/models/delivery.rb', line 22

def event
  @event
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/openapi_client/models/delivery.rb', line 18

def id
  @id
end

#replay_countObject

Returns the value of attribute replay_count.



30
31
32
# File 'lib/openapi_client/models/delivery.rb', line 30

def replay_count
  @replay_count
end

#response_statusObject

Returns the value of attribute response_status.



28
29
30
# File 'lib/openapi_client/models/delivery.rb', line 28

def response_status
  @response_status
end

#statusObject

Returns the value of attribute status.



24
25
26
# File 'lib/openapi_client/models/delivery.rb', line 24

def status
  @status
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



71
72
73
# File 'lib/openapi_client/models/delivery.rb', line 71

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



76
77
78
# File 'lib/openapi_client/models/delivery.rb', line 76

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



57
58
59
60
61
62
63
64
65
66
67
68
# File 'lib/openapi_client/models/delivery.rb', line 57

def self.attribute_map
  {
    :'id' => :'id',
    :'endpoint_id' => :'endpoint_id',
    :'event' => :'event',
    :'status' => :'status',
    :'attempt_count' => :'attempt_count',
    :'response_status' => :'response_status',
    :'replay_count' => :'replay_count',
    :'created_at' => :'created_at'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
# File 'lib/openapi_client/models/delivery.rb', line 208

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



95
96
97
98
99
100
# File 'lib/openapi_client/models/delivery.rb', line 95

def self.openapi_nullable
  Set.new([
    :'event',
    :'response_status',
  ])
end

.openapi_typesObject

Attribute type mapping.



81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/openapi_client/models/delivery.rb', line 81

def self.openapi_types
  {
    :'id' => :'String',
    :'endpoint_id' => :'String',
    :'event' => :'String',
    :'status' => :'String',
    :'attempt_count' => :'Integer',
    :'response_status' => :'Integer',
    :'replay_count' => :'Integer',
    :'created_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



180
181
182
183
184
185
186
187
188
189
190
191
# File 'lib/openapi_client/models/delivery.rb', line 180

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      endpoint_id == o.endpoint_id &&
      event == o.event &&
      status == o.status &&
      attempt_count == o.attempt_count &&
      response_status == o.response_status &&
      replay_count == o.replay_count &&
      created_at == o.created_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


195
196
197
# File 'lib/openapi_client/models/delivery.rb', line 195

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



201
202
203
# File 'lib/openapi_client/models/delivery.rb', line 201

def hash
  [id, endpoint_id, event, status, attempt_count, response_status, replay_count, created_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



153
154
155
156
157
# File 'lib/openapi_client/models/delivery.rb', line 153

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



230
231
232
233
234
235
236
237
238
239
240
241
242
# File 'lib/openapi_client/models/delivery.rb', line 230

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



161
162
163
164
165
166
# File 'lib/openapi_client/models/delivery.rb', line 161

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  status_validator = EnumAttributeValidator.new('String', ["pending", "processing", "delivered", "failed"])
  return false unless status_validator.valid?(@status)
  true
end