Class: OpenapiClient::Endpoint

Inherits:
ApiModelBase show all
Defined in:
lib/openapi_client/models/endpoint.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Endpoint

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
# File 'lib/openapi_client/models/endpoint.rb', line 133

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `OpenapiClient::Endpoint` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `OpenapiClient::Endpoint`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'url')
    self.url = attributes[:'url']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'is_active')
    self.is_active = attributes[:'is_active']
  end

  if attributes.key?(:'retry_policy')
    self.retry_policy = attributes[:'retry_policy']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'allowed_ips')
    if (value = attributes[:'allowed_ips']).is_a?(Array)
      self.allowed_ips = value
    end
  end

  if attributes.key?(:'event_filter')
    if (value = attributes[:'event_filter']).is_a?(Array)
      self.event_filter = value
    end
  end

  if attributes.key?(:'custom_headers')
    self.custom_headers = attributes[:'custom_headers']
  end

  if attributes.key?(:'routing_strategy')
    self.routing_strategy = attributes[:'routing_strategy']
  end

  if attributes.key?(:'fallback_url')
    self.fallback_url = attributes[:'fallback_url']
  end

  if attributes.key?(:'avg_response_ms')
    self.avg_response_ms = attributes[:'avg_response_ms']
  end

  if attributes.key?(:'failure_streak')
    self.failure_streak = attributes[:'failure_streak']
  end

  if attributes.key?(:'format')
    self.format = attributes[:'format']
  end
end

Instance Attribute Details

#allowed_ipsObject

CIDR blocks or exact IPs



31
32
33
# File 'lib/openapi_client/models/endpoint.rb', line 31

def allowed_ips
  @allowed_ips
end

#avg_response_msObject

Returns the value of attribute avg_response_ms.



42
43
44
# File 'lib/openapi_client/models/endpoint.rb', line 42

def avg_response_ms
  @avg_response_ms
end

#created_atObject

Returns the value of attribute created_at.



28
29
30
# File 'lib/openapi_client/models/endpoint.rb', line 28

def created_at
  @created_at
end

#custom_headersObject

Returns the value of attribute custom_headers.



36
37
38
# File 'lib/openapi_client/models/endpoint.rb', line 36

def custom_headers
  @custom_headers
end

#descriptionObject

Returns the value of attribute description.



22
23
24
# File 'lib/openapi_client/models/endpoint.rb', line 22

def description
  @description
end

#event_filterObject

Wildcard patterns (e.g. "order.*")



34
35
36
# File 'lib/openapi_client/models/endpoint.rb', line 34

def event_filter
  @event_filter
end

#failure_streakObject

Returns the value of attribute failure_streak.



44
45
46
# File 'lib/openapi_client/models/endpoint.rb', line 44

def failure_streak
  @failure_streak
end

#fallback_urlObject

Returns the value of attribute fallback_url.



40
41
42
# File 'lib/openapi_client/models/endpoint.rb', line 40

def fallback_url
  @fallback_url
end

#formatObject

Returns the value of attribute format.



46
47
48
# File 'lib/openapi_client/models/endpoint.rb', line 46

def format
  @format
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/openapi_client/models/endpoint.rb', line 18

def id
  @id
end

#is_activeObject

Returns the value of attribute is_active.



24
25
26
# File 'lib/openapi_client/models/endpoint.rb', line 24

def is_active
  @is_active
end

#retry_policyObject

Returns the value of attribute retry_policy.



26
27
28
# File 'lib/openapi_client/models/endpoint.rb', line 26

def retry_policy
  @retry_policy
end

#routing_strategyObject

Returns the value of attribute routing_strategy.



38
39
40
# File 'lib/openapi_client/models/endpoint.rb', line 38

def routing_strategy
  @routing_strategy
end

#urlObject

Returns the value of attribute url.



20
21
22
# File 'lib/openapi_client/models/endpoint.rb', line 20

def url
  @url
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



91
92
93
# File 'lib/openapi_client/models/endpoint.rb', line 91

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



96
97
98
# File 'lib/openapi_client/models/endpoint.rb', line 96

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/openapi_client/models/endpoint.rb', line 71

def self.attribute_map
  {
    :'id' => :'id',
    :'url' => :'url',
    :'description' => :'description',
    :'is_active' => :'is_active',
    :'retry_policy' => :'retry_policy',
    :'created_at' => :'created_at',
    :'allowed_ips' => :'allowed_ips',
    :'event_filter' => :'event_filter',
    :'custom_headers' => :'custom_headers',
    :'routing_strategy' => :'routing_strategy',
    :'fallback_url' => :'fallback_url',
    :'avg_response_ms' => :'avg_response_ms',
    :'failure_streak' => :'failure_streak',
    :'format' => :'format'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
# File 'lib/openapi_client/models/endpoint.rb', line 283

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



121
122
123
124
125
126
127
128
129
# File 'lib/openapi_client/models/endpoint.rb', line 121

def self.openapi_nullable
  Set.new([
    :'description',
    :'allowed_ips',
    :'event_filter',
    :'custom_headers',
    :'fallback_url',
  ])
end

.openapi_typesObject

Attribute type mapping.



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
# File 'lib/openapi_client/models/endpoint.rb', line 101

def self.openapi_types
  {
    :'id' => :'String',
    :'url' => :'String',
    :'description' => :'String',
    :'is_active' => :'Boolean',
    :'retry_policy' => :'RetryPolicy',
    :'created_at' => :'Time',
    :'allowed_ips' => :'Array<String>',
    :'event_filter' => :'Array<String>',
    :'custom_headers' => :'Object',
    :'routing_strategy' => :'String',
    :'fallback_url' => :'String',
    :'avg_response_ms' => :'Integer',
    :'failure_streak' => :'Integer',
    :'format' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
# File 'lib/openapi_client/models/endpoint.rb', line 249

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      url == o.url &&
      description == o.description &&
      is_active == o.is_active &&
      retry_policy == o.retry_policy &&
      created_at == o.created_at &&
      allowed_ips == o.allowed_ips &&
      event_filter == o.event_filter &&
      custom_headers == o.custom_headers &&
      routing_strategy == o.routing_strategy &&
      fallback_url == o.fallback_url &&
      avg_response_ms == o.avg_response_ms &&
      failure_streak == o.failure_streak &&
      format == o.format
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


270
271
272
# File 'lib/openapi_client/models/endpoint.rb', line 270

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



276
277
278
# File 'lib/openapi_client/models/endpoint.rb', line 276

def hash
  [id, url, description, is_active, retry_policy, created_at, allowed_ips, event_filter, custom_headers, routing_strategy, fallback_url, avg_response_ms, failure_streak, format].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



210
211
212
213
214
# File 'lib/openapi_client/models/endpoint.rb', line 210

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



305
306
307
308
309
310
311
312
313
314
315
316
317
# File 'lib/openapi_client/models/endpoint.rb', line 305

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



218
219
220
221
222
223
224
225
# File 'lib/openapi_client/models/endpoint.rb', line 218

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  routing_strategy_validator = EnumAttributeValidator.new('String', ["round-robin", "latency", "failover"])
  return false unless routing_strategy_validator.valid?(@routing_strategy)
  format_validator = EnumAttributeValidator.new('String', ["standard", "cloudevents"])
  return false unless format_validator.valid?(@format)
  true
end