Class: OpenapiClient::InboundApi
- Inherits:
-
Object
- Object
- OpenapiClient::InboundApi
- Defined in:
- lib/openapi_client/api/inbound_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#inbound_provider_endpoint_id_post(provider, endpoint_id, body, opts = {}) ⇒ nil
Receive inbound webhook for a specific endpoint.
-
#inbound_provider_endpoint_id_post_with_http_info(provider, endpoint_id, body, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Receive inbound webhook for a specific endpoint.
-
#inbound_provider_post(provider, body, opts = {}) ⇒ nil
Receive inbound webhook from a provider Accepts webhooks from external providers (Stripe, GitHub, etc.) and routes them to the customer’s endpoints.
-
#inbound_provider_post_with_http_info(provider, body, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Receive inbound webhook from a provider Accepts webhooks from external providers (Stripe, GitHub, etc.) and routes them to the customer's endpoints.
-
#initialize(api_client = ApiClient.default) ⇒ InboundApi
constructor
A new instance of InboundApi.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ InboundApi
Returns a new instance of InboundApi.
19 20 21 |
# File 'lib/openapi_client/api/inbound_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/openapi_client/api/inbound_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#inbound_provider_endpoint_id_post(provider, endpoint_id, body, opts = {}) ⇒ nil
Receive inbound webhook for a specific endpoint
28 29 30 31 |
# File 'lib/openapi_client/api/inbound_api.rb', line 28 def inbound_provider_endpoint_id_post(provider, endpoint_id, body, opts = {}) inbound_provider_endpoint_id_post_with_http_info(provider, endpoint_id, body, opts) nil end |
#inbound_provider_endpoint_id_post_with_http_info(provider, endpoint_id, body, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Receive inbound webhook for a specific endpoint
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/openapi_client/api/inbound_api.rb', line 39 def inbound_provider_endpoint_id_post_with_http_info(provider, endpoint_id, body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: InboundApi.inbound_provider_endpoint_id_post ...' end # verify the required parameter 'provider' is set if @api_client.config.client_side_validation && provider.nil? fail ArgumentError, "Missing the required parameter 'provider' when calling InboundApi.inbound_provider_endpoint_id_post" end # verify the required parameter 'endpoint_id' is set if @api_client.config.client_side_validation && endpoint_id.nil? fail ArgumentError, "Missing the required parameter 'endpoint_id' when calling InboundApi.inbound_provider_endpoint_id_post" end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling InboundApi.inbound_provider_endpoint_id_post" end # resource path local_var_path = '/inbound/{provider}/{endpoint_id}'.sub('{provider}', CGI.escape(provider.to_s)).sub('{endpoint_id}', CGI.escape(endpoint_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(body) # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['BearerAuth'] = opts.merge( :operation => :"InboundApi.inbound_provider_endpoint_id_post", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: InboundApi#inbound_provider_endpoint_id_post\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#inbound_provider_post(provider, body, opts = {}) ⇒ nil
Receive inbound webhook from a provider Accepts webhooks from external providers (Stripe, GitHub, etc.) and routes them to the customer’s endpoints.
104 105 106 107 |
# File 'lib/openapi_client/api/inbound_api.rb', line 104 def inbound_provider_post(provider, body, opts = {}) inbound_provider_post_with_http_info(provider, body, opts) nil end |
#inbound_provider_post_with_http_info(provider, body, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Receive inbound webhook from a provider Accepts webhooks from external providers (Stripe, GitHub, etc.) and routes them to the customer's endpoints.
115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 |
# File 'lib/openapi_client/api/inbound_api.rb', line 115 def inbound_provider_post_with_http_info(provider, body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: InboundApi.inbound_provider_post ...' end # verify the required parameter 'provider' is set if @api_client.config.client_side_validation && provider.nil? fail ArgumentError, "Missing the required parameter 'provider' when calling InboundApi.inbound_provider_post" end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling InboundApi.inbound_provider_post" end # resource path local_var_path = '/inbound/{provider}'.sub('{provider}', CGI.escape(provider.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(body) # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['BearerAuth'] = opts.merge( :operation => :"InboundApi.inbound_provider_post", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: InboundApi#inbound_provider_post\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |