Class: OpenapiClient::NotificationPreferences
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- OpenapiClient::NotificationPreferences
- Defined in:
- lib/openapi_client/models/notification_preferences.rb
Instance Attribute Summary collapse
-
#discord_webhook_url ⇒ Object
Returns the value of attribute discord_webhook_url.
-
#email_on_dead_letter ⇒ Object
Returns the value of attribute email_on_dead_letter.
-
#email_on_failure ⇒ Object
Returns the value of attribute email_on_failure.
-
#email_on_success ⇒ Object
Returns the value of attribute email_on_success.
-
#slack_webhook_url ⇒ Object
Returns the value of attribute slack_webhook_url.
-
#webhook_url ⇒ Object
Returns the value of attribute webhook_url.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ NotificationPreferences
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ NotificationPreferences
Initializes the object
75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 |
# File 'lib/openapi_client/models/notification_preferences.rb', line 75 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `OpenapiClient::NotificationPreferences` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `OpenapiClient::NotificationPreferences`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'email_on_failure') self.email_on_failure = attributes[:'email_on_failure'] else self.email_on_failure = true end if attributes.key?(:'email_on_dead_letter') self.email_on_dead_letter = attributes[:'email_on_dead_letter'] else self.email_on_dead_letter = true end if attributes.key?(:'email_on_success') self.email_on_success = attributes[:'email_on_success'] else self.email_on_success = false end if attributes.key?(:'slack_webhook_url') self.slack_webhook_url = attributes[:'slack_webhook_url'] end if attributes.key?(:'discord_webhook_url') self.discord_webhook_url = attributes[:'discord_webhook_url'] end if attributes.key?(:'webhook_url') self.webhook_url = attributes[:'webhook_url'] end end |
Instance Attribute Details
#discord_webhook_url ⇒ Object
Returns the value of attribute discord_webhook_url.
26 27 28 |
# File 'lib/openapi_client/models/notification_preferences.rb', line 26 def discord_webhook_url @discord_webhook_url end |
#email_on_dead_letter ⇒ Object
Returns the value of attribute email_on_dead_letter.
20 21 22 |
# File 'lib/openapi_client/models/notification_preferences.rb', line 20 def email_on_dead_letter @email_on_dead_letter end |
#email_on_failure ⇒ Object
Returns the value of attribute email_on_failure.
18 19 20 |
# File 'lib/openapi_client/models/notification_preferences.rb', line 18 def email_on_failure @email_on_failure end |
#email_on_success ⇒ Object
Returns the value of attribute email_on_success.
22 23 24 |
# File 'lib/openapi_client/models/notification_preferences.rb', line 22 def email_on_success @email_on_success end |
#slack_webhook_url ⇒ Object
Returns the value of attribute slack_webhook_url.
24 25 26 |
# File 'lib/openapi_client/models/notification_preferences.rb', line 24 def slack_webhook_url @slack_webhook_url end |
#webhook_url ⇒ Object
Returns the value of attribute webhook_url.
28 29 30 |
# File 'lib/openapi_client/models/notification_preferences.rb', line 28 def webhook_url @webhook_url end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
43 44 45 |
# File 'lib/openapi_client/models/notification_preferences.rb', line 43 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
48 49 50 |
# File 'lib/openapi_client/models/notification_preferences.rb', line 48 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
31 32 33 34 35 36 37 38 39 40 |
# File 'lib/openapi_client/models/notification_preferences.rb', line 31 def self.attribute_map { :'email_on_failure' => :'email_on_failure', :'email_on_dead_letter' => :'email_on_dead_letter', :'email_on_success' => :'email_on_success', :'slack_webhook_url' => :'slack_webhook_url', :'discord_webhook_url' => :'discord_webhook_url', :'webhook_url' => :'webhook_url' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 |
# File 'lib/openapi_client/models/notification_preferences.rb', line 163 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
65 66 67 68 69 70 71 |
# File 'lib/openapi_client/models/notification_preferences.rb', line 65 def self.openapi_nullable Set.new([ :'slack_webhook_url', :'discord_webhook_url', :'webhook_url' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
53 54 55 56 57 58 59 60 61 62 |
# File 'lib/openapi_client/models/notification_preferences.rb', line 53 def self.openapi_types { :'email_on_failure' => :'Boolean', :'email_on_dead_letter' => :'Boolean', :'email_on_success' => :'Boolean', :'slack_webhook_url' => :'String', :'discord_webhook_url' => :'String', :'webhook_url' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
137 138 139 140 141 142 143 144 145 146 |
# File 'lib/openapi_client/models/notification_preferences.rb', line 137 def ==(o) return true if self.equal?(o) self.class == o.class && email_on_failure == o.email_on_failure && email_on_dead_letter == o.email_on_dead_letter && email_on_success == o.email_on_success && slack_webhook_url == o.slack_webhook_url && discord_webhook_url == o.discord_webhook_url && webhook_url == o.webhook_url end |
#eql?(o) ⇒ Boolean
150 151 152 |
# File 'lib/openapi_client/models/notification_preferences.rb', line 150 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
156 157 158 |
# File 'lib/openapi_client/models/notification_preferences.rb', line 156 def hash [email_on_failure, email_on_dead_letter, email_on_success, slack_webhook_url, discord_webhook_url, webhook_url].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
122 123 124 125 126 |
# File 'lib/openapi_client/models/notification_preferences.rb', line 122 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
185 186 187 188 189 190 191 192 193 194 195 196 197 |
# File 'lib/openapi_client/models/notification_preferences.rb', line 185 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
130 131 132 133 |
# File 'lib/openapi_client/models/notification_preferences.rb', line 130 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |