Class: OpenapiClient::RetryPolicy
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- OpenapiClient::RetryPolicy
- Defined in:
- lib/openapi_client/models/retry_policy.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#backoff ⇒ Object
Returns the value of attribute backoff.
-
#initial_delay_secs ⇒ Object
Returns the value of attribute initial_delay_secs.
-
#max_attempts ⇒ Object
Returns the value of attribute max_attempts.
-
#max_delay_secs ⇒ Object
Returns the value of attribute max_delay_secs.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RetryPolicy
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ RetryPolicy
Initializes the object
86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 |
# File 'lib/openapi_client/models/retry_policy.rb', line 86 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `OpenapiClient::RetryPolicy` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `OpenapiClient::RetryPolicy`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'max_attempts') self.max_attempts = attributes[:'max_attempts'] else self.max_attempts = 3 end if attributes.key?(:'backoff') self.backoff = attributes[:'backoff'] else self.backoff = 'exponential' end if attributes.key?(:'initial_delay_secs') self.initial_delay_secs = attributes[:'initial_delay_secs'] else self.initial_delay_secs = 10 end if attributes.key?(:'max_delay_secs') self.max_delay_secs = attributes[:'max_delay_secs'] else self.max_delay_secs = 3600 end end |
Instance Attribute Details
#backoff ⇒ Object
Returns the value of attribute backoff.
20 21 22 |
# File 'lib/openapi_client/models/retry_policy.rb', line 20 def backoff @backoff end |
#initial_delay_secs ⇒ Object
Returns the value of attribute initial_delay_secs.
22 23 24 |
# File 'lib/openapi_client/models/retry_policy.rb', line 22 def initial_delay_secs @initial_delay_secs end |
#max_attempts ⇒ Object
Returns the value of attribute max_attempts.
18 19 20 |
# File 'lib/openapi_client/models/retry_policy.rb', line 18 def max_attempts @max_attempts end |
#max_delay_secs ⇒ Object
Returns the value of attribute max_delay_secs.
24 25 26 |
# File 'lib/openapi_client/models/retry_policy.rb', line 24 def max_delay_secs @max_delay_secs end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
59 60 61 |
# File 'lib/openapi_client/models/retry_policy.rb', line 59 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
64 65 66 |
# File 'lib/openapi_client/models/retry_policy.rb', line 64 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
49 50 51 52 53 54 55 56 |
# File 'lib/openapi_client/models/retry_policy.rb', line 49 def self.attribute_map { :'max_attempts' => :'max_attempts', :'backoff' => :'backoff', :'initial_delay_secs' => :'initial_delay_secs', :'max_delay_secs' => :'max_delay_secs' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 |
# File 'lib/openapi_client/models/retry_policy.rb', line 178 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
79 80 81 82 |
# File 'lib/openapi_client/models/retry_policy.rb', line 79 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
69 70 71 72 73 74 75 76 |
# File 'lib/openapi_client/models/retry_policy.rb', line 69 def self.openapi_types { :'max_attempts' => :'Integer', :'backoff' => :'String', :'initial_delay_secs' => :'Integer', :'max_delay_secs' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
154 155 156 157 158 159 160 161 |
# File 'lib/openapi_client/models/retry_policy.rb', line 154 def ==(o) return true if self.equal?(o) self.class == o.class && max_attempts == o.max_attempts && backoff == o.backoff && initial_delay_secs == o.initial_delay_secs && max_delay_secs == o.max_delay_secs end |
#eql?(o) ⇒ Boolean
165 166 167 |
# File 'lib/openapi_client/models/retry_policy.rb', line 165 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
171 172 173 |
# File 'lib/openapi_client/models/retry_policy.rb', line 171 def hash [max_attempts, backoff, initial_delay_secs, max_delay_secs].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
127 128 129 130 131 |
# File 'lib/openapi_client/models/retry_policy.rb', line 127 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
200 201 202 203 204 205 206 207 208 209 210 211 212 |
# File 'lib/openapi_client/models/retry_policy.rb', line 200 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
135 136 137 138 139 140 |
# File 'lib/openapi_client/models/retry_policy.rb', line 135 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' backoff_validator = EnumAttributeValidator.new('String', ["exponential", "linear", "fixed"]) return false unless backoff_validator.valid?(@backoff) true end |