Class: OpenapiClient::RoutingInfo
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- OpenapiClient::RoutingInfo
- Defined in:
- lib/openapi_client/models/routing_info.rb
Instance Attribute Summary collapse
-
#avg_response_ms ⇒ Object
Returns the value of attribute avg_response_ms.
-
#endpoint_id ⇒ Object
Returns the value of attribute endpoint_id.
-
#failure_streak ⇒ Object
Returns the value of attribute failure_streak.
-
#fallback_url ⇒ Object
Returns the value of attribute fallback_url.
-
#is_healthy ⇒ Object
Returns the value of attribute is_healthy.
-
#routing_strategy ⇒ Object
Returns the value of attribute routing_strategy.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RoutingInfo
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ RoutingInfo
Initializes the object
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/openapi_client/models/routing_info.rb', line 73 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `OpenapiClient::RoutingInfo` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `OpenapiClient::RoutingInfo`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'endpoint_id') self.endpoint_id = attributes[:'endpoint_id'] end if attributes.key?(:'routing_strategy') self.routing_strategy = attributes[:'routing_strategy'] end if attributes.key?(:'fallback_url') self.fallback_url = attributes[:'fallback_url'] end if attributes.key?(:'avg_response_ms') self.avg_response_ms = attributes[:'avg_response_ms'] end if attributes.key?(:'failure_streak') self.failure_streak = attributes[:'failure_streak'] end if attributes.key?(:'is_healthy') self.is_healthy = attributes[:'is_healthy'] end end |
Instance Attribute Details
#avg_response_ms ⇒ Object
Returns the value of attribute avg_response_ms.
24 25 26 |
# File 'lib/openapi_client/models/routing_info.rb', line 24 def avg_response_ms @avg_response_ms end |
#endpoint_id ⇒ Object
Returns the value of attribute endpoint_id.
18 19 20 |
# File 'lib/openapi_client/models/routing_info.rb', line 18 def endpoint_id @endpoint_id end |
#failure_streak ⇒ Object
Returns the value of attribute failure_streak.
26 27 28 |
# File 'lib/openapi_client/models/routing_info.rb', line 26 def failure_streak @failure_streak end |
#fallback_url ⇒ Object
Returns the value of attribute fallback_url.
22 23 24 |
# File 'lib/openapi_client/models/routing_info.rb', line 22 def fallback_url @fallback_url end |
#is_healthy ⇒ Object
Returns the value of attribute is_healthy.
28 29 30 |
# File 'lib/openapi_client/models/routing_info.rb', line 28 def is_healthy @is_healthy end |
#routing_strategy ⇒ Object
Returns the value of attribute routing_strategy.
20 21 22 |
# File 'lib/openapi_client/models/routing_info.rb', line 20 def routing_strategy @routing_strategy end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
43 44 45 |
# File 'lib/openapi_client/models/routing_info.rb', line 43 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
48 49 50 |
# File 'lib/openapi_client/models/routing_info.rb', line 48 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
31 32 33 34 35 36 37 38 39 40 |
# File 'lib/openapi_client/models/routing_info.rb', line 31 def self.attribute_map { :'endpoint_id' => :'endpoint_id', :'routing_strategy' => :'routing_strategy', :'fallback_url' => :'fallback_url', :'avg_response_ms' => :'avg_response_ms', :'failure_streak' => :'failure_streak', :'is_healthy' => :'is_healthy' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 |
# File 'lib/openapi_client/models/routing_info.rb', line 155 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
65 66 67 68 69 |
# File 'lib/openapi_client/models/routing_info.rb', line 65 def self.openapi_nullable Set.new([ :'fallback_url', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
53 54 55 56 57 58 59 60 61 62 |
# File 'lib/openapi_client/models/routing_info.rb', line 53 def self.openapi_types { :'endpoint_id' => :'String', :'routing_strategy' => :'String', :'fallback_url' => :'String', :'avg_response_ms' => :'Integer', :'failure_streak' => :'Integer', :'is_healthy' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
129 130 131 132 133 134 135 136 137 138 |
# File 'lib/openapi_client/models/routing_info.rb', line 129 def ==(o) return true if self.equal?(o) self.class == o.class && endpoint_id == o.endpoint_id && routing_strategy == o.routing_strategy && fallback_url == o.fallback_url && avg_response_ms == o.avg_response_ms && failure_streak == o.failure_streak && is_healthy == o.is_healthy end |
#eql?(o) ⇒ Boolean
142 143 144 |
# File 'lib/openapi_client/models/routing_info.rb', line 142 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
148 149 150 |
# File 'lib/openapi_client/models/routing_info.rb', line 148 def hash [endpoint_id, routing_strategy, fallback_url, avg_response_ms, failure_streak, is_healthy].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
114 115 116 117 118 |
# File 'lib/openapi_client/models/routing_info.rb', line 114 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
177 178 179 180 181 182 183 184 185 186 187 188 189 |
# File 'lib/openapi_client/models/routing_info.rb', line 177 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
122 123 124 125 |
# File 'lib/openapi_client/models/routing_info.rb', line 122 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |