Class: OpenapiClient::SystemStatusComponentsInner
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- OpenapiClient::SystemStatusComponentsInner
- Defined in:
- lib/openapi_client/models/system_status_components_inner.rb
Instance Attribute Summary collapse
-
#description ⇒ Object
Returns the value of attribute description.
-
#last_checked ⇒ Object
Returns the value of attribute last_checked.
-
#latency_ms ⇒ Object
Returns the value of attribute latency_ms.
-
#name ⇒ Object
Returns the value of attribute name.
-
#status ⇒ Object
Returns the value of attribute status.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SystemStatusComponentsInner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ SystemStatusComponentsInner
Initializes the object
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/openapi_client/models/system_status_components_inner.rb', line 69 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `OpenapiClient::SystemStatusComponentsInner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `OpenapiClient::SystemStatusComponentsInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'latency_ms') self.latency_ms = attributes[:'latency_ms'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'last_checked') self.last_checked = attributes[:'last_checked'] end end |
Instance Attribute Details
#description ⇒ Object
Returns the value of attribute description.
24 25 26 |
# File 'lib/openapi_client/models/system_status_components_inner.rb', line 24 def description @description end |
#last_checked ⇒ Object
Returns the value of attribute last_checked.
26 27 28 |
# File 'lib/openapi_client/models/system_status_components_inner.rb', line 26 def last_checked @last_checked end |
#latency_ms ⇒ Object
Returns the value of attribute latency_ms.
22 23 24 |
# File 'lib/openapi_client/models/system_status_components_inner.rb', line 22 def latency_ms @latency_ms end |
#name ⇒ Object
Returns the value of attribute name.
18 19 20 |
# File 'lib/openapi_client/models/system_status_components_inner.rb', line 18 def name @name end |
#status ⇒ Object
Returns the value of attribute status.
20 21 22 |
# File 'lib/openapi_client/models/system_status_components_inner.rb', line 20 def status @status end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
40 41 42 |
# File 'lib/openapi_client/models/system_status_components_inner.rb', line 40 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
45 46 47 |
# File 'lib/openapi_client/models/system_status_components_inner.rb', line 45 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
29 30 31 32 33 34 35 36 37 |
# File 'lib/openapi_client/models/system_status_components_inner.rb', line 29 def self.attribute_map { :'name' => :'name', :'status' => :'status', :'latency_ms' => :'latency_ms', :'description' => :'description', :'last_checked' => :'last_checked' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 |
# File 'lib/openapi_client/models/system_status_components_inner.rb', line 146 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
61 62 63 64 65 |
# File 'lib/openapi_client/models/system_status_components_inner.rb', line 61 def self.openapi_nullable Set.new([ :'latency_ms', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
50 51 52 53 54 55 56 57 58 |
# File 'lib/openapi_client/models/system_status_components_inner.rb', line 50 def self.openapi_types { :'name' => :'String', :'status' => :'String', :'latency_ms' => :'Integer', :'description' => :'String', :'last_checked' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
121 122 123 124 125 126 127 128 129 |
# File 'lib/openapi_client/models/system_status_components_inner.rb', line 121 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && status == o.status && latency_ms == o.latency_ms && description == o.description && last_checked == o.last_checked end |
#eql?(o) ⇒ Boolean
133 134 135 |
# File 'lib/openapi_client/models/system_status_components_inner.rb', line 133 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
139 140 141 |
# File 'lib/openapi_client/models/system_status_components_inner.rb', line 139 def hash [name, status, latency_ms, description, last_checked].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
106 107 108 109 110 |
# File 'lib/openapi_client/models/system_status_components_inner.rb', line 106 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
168 169 170 171 172 173 174 175 176 177 178 179 180 |
# File 'lib/openapi_client/models/system_status_components_inner.rb', line 168 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
114 115 116 117 |
# File 'lib/openapi_client/models/system_status_components_inner.rb', line 114 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |