Class: OpenapiClient::UpdateEndpointRequest

Inherits:
ApiModelBase show all
Defined in:
lib/openapi_client/models/update_endpoint_request.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ UpdateEndpointRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
# File 'lib/openapi_client/models/update_endpoint_request.rb', line 110

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `OpenapiClient::UpdateEndpointRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `OpenapiClient::UpdateEndpointRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'url')
    self.url = attributes[:'url']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'is_active')
    self.is_active = attributes[:'is_active']
  end

  if attributes.key?(:'allowed_ips')
    if (value = attributes[:'allowed_ips']).is_a?(Array)
      self.allowed_ips = value
    end
  end

  if attributes.key?(:'event_filter')
    if (value = attributes[:'event_filter']).is_a?(Array)
      self.event_filter = value
    end
  end

  if attributes.key?(:'custom_headers')
    self.custom_headers = attributes[:'custom_headers']
  end

  if attributes.key?(:'retry_policy')
    self.retry_policy = attributes[:'retry_policy']
  end

  if attributes.key?(:'routing_strategy')
    self.routing_strategy = attributes[:'routing_strategy']
  end

  if attributes.key?(:'fallback_url')
    self.fallback_url = attributes[:'fallback_url']
  end

  if attributes.key?(:'format')
    self.format = attributes[:'format']
  end
end

Instance Attribute Details

#allowed_ipsObject

Returns the value of attribute allowed_ips.



24
25
26
# File 'lib/openapi_client/models/update_endpoint_request.rb', line 24

def allowed_ips
  @allowed_ips
end

#custom_headersObject

Returns the value of attribute custom_headers.



28
29
30
# File 'lib/openapi_client/models/update_endpoint_request.rb', line 28

def custom_headers
  @custom_headers
end

#descriptionObject

Returns the value of attribute description.



20
21
22
# File 'lib/openapi_client/models/update_endpoint_request.rb', line 20

def description
  @description
end

#event_filterObject

Returns the value of attribute event_filter.



26
27
28
# File 'lib/openapi_client/models/update_endpoint_request.rb', line 26

def event_filter
  @event_filter
end

#fallback_urlObject

Returns the value of attribute fallback_url.



34
35
36
# File 'lib/openapi_client/models/update_endpoint_request.rb', line 34

def fallback_url
  @fallback_url
end

#formatObject

Returns the value of attribute format.



36
37
38
# File 'lib/openapi_client/models/update_endpoint_request.rb', line 36

def format
  @format
end

#is_activeObject

Returns the value of attribute is_active.



22
23
24
# File 'lib/openapi_client/models/update_endpoint_request.rb', line 22

def is_active
  @is_active
end

#retry_policyObject

Returns the value of attribute retry_policy.



30
31
32
# File 'lib/openapi_client/models/update_endpoint_request.rb', line 30

def retry_policy
  @retry_policy
end

#routing_strategyObject

Returns the value of attribute routing_strategy.



32
33
34
# File 'lib/openapi_client/models/update_endpoint_request.rb', line 32

def routing_strategy
  @routing_strategy
end

#urlObject

Returns the value of attribute url.



18
19
20
# File 'lib/openapi_client/models/update_endpoint_request.rb', line 18

def url
  @url
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



77
78
79
# File 'lib/openapi_client/models/update_endpoint_request.rb', line 77

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



82
83
84
# File 'lib/openapi_client/models/update_endpoint_request.rb', line 82

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



61
62
63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/openapi_client/models/update_endpoint_request.rb', line 61

def self.attribute_map
  {
    :'url' => :'url',
    :'description' => :'description',
    :'is_active' => :'is_active',
    :'allowed_ips' => :'allowed_ips',
    :'event_filter' => :'event_filter',
    :'custom_headers' => :'custom_headers',
    :'retry_policy' => :'retry_policy',
    :'routing_strategy' => :'routing_strategy',
    :'fallback_url' => :'fallback_url',
    :'format' => :'format'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
# File 'lib/openapi_client/models/update_endpoint_request.rb', line 240

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



103
104
105
106
# File 'lib/openapi_client/models/update_endpoint_request.rb', line 103

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



87
88
89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/openapi_client/models/update_endpoint_request.rb', line 87

def self.openapi_types
  {
    :'url' => :'String',
    :'description' => :'String',
    :'is_active' => :'Boolean',
    :'allowed_ips' => :'Array<String>',
    :'event_filter' => :'Array<String>',
    :'custom_headers' => :'Object',
    :'retry_policy' => :'RetryPolicy',
    :'routing_strategy' => :'String',
    :'fallback_url' => :'String',
    :'format' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



210
211
212
213
214
215
216
217
218
219
220
221
222
223
# File 'lib/openapi_client/models/update_endpoint_request.rb', line 210

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      url == o.url &&
      description == o.description &&
      is_active == o.is_active &&
      allowed_ips == o.allowed_ips &&
      event_filter == o.event_filter &&
      custom_headers == o.custom_headers &&
      retry_policy == o.retry_policy &&
      routing_strategy == o.routing_strategy &&
      fallback_url == o.fallback_url &&
      format == o.format
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


227
228
229
# File 'lib/openapi_client/models/update_endpoint_request.rb', line 227

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



233
234
235
# File 'lib/openapi_client/models/update_endpoint_request.rb', line 233

def hash
  [url, description, is_active, allowed_ips, event_filter, custom_headers, retry_policy, routing_strategy, fallback_url, format].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



171
172
173
174
175
# File 'lib/openapi_client/models/update_endpoint_request.rb', line 171

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



262
263
264
265
266
267
268
269
270
271
272
273
274
# File 'lib/openapi_client/models/update_endpoint_request.rb', line 262

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



179
180
181
182
183
184
185
186
# File 'lib/openapi_client/models/update_endpoint_request.rb', line 179

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  routing_strategy_validator = EnumAttributeValidator.new('String', ["round-robin", "latency", "failover"])
  return false unless routing_strategy_validator.valid?(@routing_strategy)
  format_validator = EnumAttributeValidator.new('String', ["standard", "cloudevents"])
  return false unless format_validator.valid?(@format)
  true
end